from typing import Any

from django.urls import path

from ..views import transcript as views

urlpatterns: list[Any] = [
    path("transcript", views.index, name="index"),
    path(r"transcript/add/", views.add, name="add"),
    path("transcript/edit/<int:transcript_id>/", views.edit, name="edit"),
    path("transcript/delete/<int:transcript_id>/", views.delete, name="delete"),
    path("transcript/chooser/", views.chooser, name="chooser"),
    path("transcript/chooser/upload/", views.chooser_upload, name="chooser_upload"),
    path("transcript/chooser/<int:transcript_id>/", views.chosen, name="chosen"),
]



from django.db import models
from wagtail.models import CollectionMember
from wagtail.search import index

from . import Audio


class Transcript(CollectionMember, index.Indexed, models.Model):
    audio = models.OneToOneField(Audio, on_delete=models.CASCADE, related_name="transcript")
    podlove = models.FileField(
        upload_to="cast_transcript/",
        null=True,
        blank=True,
        verbose_name="Podlove Transcript",
        help_text="The transcript format for the Podlove Web Player",
    )
    vtt = models.FileField(
        upload_to="cast_transcript/",
        null=True,
        blank=True,
        verbose_name="WebVTT Transcript",
        help_text="The WebVTT format for feed / podcatchers",
    )
    dote = models.FileField(
        upload_to="cast_transcript/",
        null=True,
        blank=True,
        verbose_name="DOTe Transcript",
        help_text="The DOTe json format for feed / podcatchers",
    )

    admin_form_fields: tuple[str, ...] = ("audio", "podlove", "vtt", "dote")

    class Meta:
        ordering = ("-id",)



from django.apps import AppConfig


class CastConfig(AppConfig):
    name: str = "cast"

    def ready(self) -> None:
        from .appsettings import init_cast_settings

        init_cast_settings()
